summaryrefslogtreecommitdiffstats
path: root/src/screen.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/screen.h')
-rw-r--r--src/screen.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/screen.h b/src/screen.h
index 7dc58b5..6d7fe9b 100644
--- a/src/screen.h
+++ b/src/screen.h
@@ -66,16 +66,16 @@ private:
* commandos to the active KScreensaver.
*/
DCOPRef screen_save_dcop_ref;
- //! KProcess to start xlock to lock the screen
- KProcess *xlock;
- //! KProcess to start xscreensaver with lock command
- KProcess *xscreensaver_lock;
- //! KProcess to start xscreensaver with restart command
- KProcess *xscreensaver_reset;
- //! KProcess to start gnome-screen-saver with lock command
- KProcess *gnomescreensaver_lock;
- //! KProcess to check if gnome-screensaver is running
- KProcess *gnomeScreensaverCheck;
+ //! TDEProcess to start xlock to lock the screen
+ TDEProcess *xlock;
+ //! TDEProcess to start xscreensaver with lock command
+ TDEProcess *xscreensaver_lock;
+ //! TDEProcess to start xscreensaver with restart command
+ TDEProcess *xscreensaver_reset;
+ //! TDEProcess to start gnome-screen-saver with lock command
+ TDEProcess *gnomescreensaver_lock;
+ //! TDEProcess to check if gnome-screensaver is running
+ TDEProcess *gnomeScreensaverCheck;
//! contains information about Xscreensaver
/*!
@@ -120,9 +120,9 @@ private slots:
//! to ping and deactivate the Xscreensaver
void xscreensaver_ping();
//! to get the return value of gnomescreensaver-command
- void getGSExited(KProcess *);
+ void getGSExited(TDEProcess *);
- void cleanProcess(KProcess *);
+ void cleanProcess(TDEProcess *);
public slots: